lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [5127] Include boost headers less promiscuously


From: Greg Chicares
Subject: [lmi-commits] [5127] Include boost headers less promiscuously
Date: Tue, 14 Dec 2010 20:39:52 +0000

Revision: 5127
          http://svn.sv.gnu.org/viewvc/?view=rev&root=lmi&revision=5127
Author:   chicares
Date:     2010-12-14 20:39:51 +0000 (Tue, 14 Dec 2010)
Log Message:
-----------
Include boost headers less promiscuously

Modified Paths:
--------------
    lmi/trunk/ChangeLog
    lmi/trunk/about_dialog.hpp
    lmi/trunk/account_value.hpp
    lmi/trunk/actuarial_table.hpp
    lmi/trunk/any_member.hpp
    lmi/trunk/authenticity.hpp
    lmi/trunk/basic_values.hpp
    lmi/trunk/callback.hpp
    lmi/trunk/census_document.hpp
    lmi/trunk/census_view.hpp
    lmi/trunk/commutation_functions.hpp
    lmi/trunk/configurable_settings.hpp
    lmi/trunk/database.hpp
    lmi/trunk/database_view.hpp
    lmi/trunk/dbdict.hpp
    lmi/trunk/death_benefits.hpp
    lmi/trunk/docmanager_ex.hpp
    lmi/trunk/docmdichildframe_ex.hpp
    lmi/trunk/fenv_guard.hpp
    lmi/trunk/file_command.hpp
    lmi/trunk/fund_data.hpp
    lmi/trunk/global_settings.hpp
    lmi/trunk/icon_monger.hpp
    lmi/trunk/ihs_irc7702.hpp
    lmi/trunk/illustration_document.hpp
    lmi/trunk/illustration_view.hpp
    lmi/trunk/input_sequence.hpp
    lmi/trunk/ledger_text_formats.cpp
    lmi/trunk/ledgervalues.hpp
    lmi/trunk/loads_impl.hpp
    lmi/trunk/main_wx.hpp
    lmi/trunk/mec_document.hpp
    lmi/trunk/mec_view.hpp
    lmi/trunk/mec_xml_document.hpp
    lmi/trunk/msw_workarounds.hpp
    lmi/trunk/multidimgrid_any.cpp
    lmi/trunk/multidimgrid_any.hpp
    lmi/trunk/multidimgrid_tools.hpp
    lmi/trunk/multiple_cell_document.hpp
    lmi/trunk/mvc_controller.hpp
    lmi/trunk/name_value_pairs.hpp
    lmi/trunk/null_stream.cpp
    lmi/trunk/outlay.hpp
    lmi/trunk/policy_view.hpp
    lmi/trunk/product_data.hpp
    lmi/trunk/product_editor.hpp
    lmi/trunk/progress_meter.hpp
    lmi/trunk/rounding_rules.hpp
    lmi/trunk/rounding_view.hpp
    lmi/trunk/single_cell_document.hpp
    lmi/trunk/test_coding_rules.cpp
    lmi/trunk/text_view.hpp
    lmi/trunk/tier_view.hpp
    lmi/trunk/timer.hpp
    lmi/trunk/transferor.hpp
    lmi/trunk/view_ex.hpp
    lmi/trunk/xml_lmi.hpp
    lmi/trunk/yare_input.hpp

Added Paths:
-----------
    lmi/trunk/uncopyable_lmi.hpp

Modified: lmi/trunk/ChangeLog
===================================================================
--- lmi/trunk/ChangeLog 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/ChangeLog 2010-12-14 20:39:51 UTC (rev 5127)
@@ -26933,3 +26933,67 @@
 rejects 'type_with_alignment.hpp'; lmi has no need of it, but it was
 haphazardly included by 'type_traits.hpp'.
 
+20101214T2039Z <address@hidden> [656]
+
+  about_dialog.hpp
+  account_value.hpp
+  actuarial_table.hpp
+  any_member.hpp
+  authenticity.hpp
+  basic_values.hpp
+  callback.hpp
+  census_document.hpp
+  census_view.hpp
+  commutation_functions.hpp
+  configurable_settings.hpp
+  database.hpp
+  database_view.hpp
+  dbdict.hpp
+  death_benefits.hpp
+  docmanager_ex.hpp
+  docmdichildframe_ex.hpp
+  fenv_guard.hpp
+  file_command.hpp
+  fund_data.hpp
+  global_settings.hpp
+  icon_monger.hpp
+  ihs_irc7702.hpp
+  illustration_document.hpp
+  illustration_view.hpp
+  input_sequence.hpp
+  ledger_text_formats.cpp
+  ledgervalues.hpp
+  loads_impl.hpp
+  main_wx.hpp
+  mec_document.hpp
+  mec_view.hpp
+  mec_xml_document.hpp
+  msw_workarounds.hpp
+  multidimgrid_any.cpp
+  multidimgrid_any.hpp
+  multidimgrid_tools.hpp
+  multiple_cell_document.hpp
+  mvc_controller.hpp
+  name_value_pairs.hpp
+  null_stream.cpp
+  outlay.hpp
+  policy_view.hpp
+  product_data.hpp
+  product_editor.hpp
+  progress_meter.hpp
+  rounding_rules.hpp
+  rounding_view.hpp
+  single_cell_document.hpp
+  test_coding_rules.cpp
+  text_view.hpp
+  tier_view.hpp
+  timer.hpp
+  transferor.hpp
+  uncopyable_lmi.hpp [new file]
+  view_ex.hpp
+  xml_lmi.hpp
+  yare_input.hpp
+Include boost headers less promiscuously. The latest version of Comeau
+rejects 'base_from_member.hpp'; lmi has no need of it, but it was
+haphazardly included by 'utility.hpp'.
+

Modified: lmi/trunk/about_dialog.hpp
===================================================================
--- lmi/trunk/about_dialog.hpp  2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/about_dialog.hpp  2010-12-14 20:39:51 UTC (rev 5127)
@@ -26,7 +26,7 @@
 
 #include "config.hpp"
 
-#include <boost/utility.hpp>
+#include "uncopyable_lmi.hpp"
 
 #include <wx/dialog.h>
 
@@ -54,7 +54,7 @@
 
 class AboutDialog
     :public wxDialog
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
   public:
     AboutDialog(wxWindow* parent);

Modified: lmi/trunk/account_value.hpp
===================================================================
--- lmi/trunk/account_value.hpp 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/account_value.hpp 2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,9 +29,9 @@
 #include "basic_values.hpp"
 #include "oecumenic_enumerations.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <iosfwd>
 #include <fstream>
@@ -51,7 +51,7 @@
 
 class LMI_SO AccountValue
     :protected BasicValues
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
 {
     friend class SolveHelper;
     friend class run_census_in_parallel;

Modified: lmi/trunk/actuarial_table.hpp
===================================================================
--- lmi/trunk/actuarial_table.hpp       2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/actuarial_table.hpp       2010-12-14 20:39:51 UTC (rev 5127)
@@ -27,9 +27,8 @@
 #include "config.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <iosfwd>
 #include <string>
 #include <vector>
@@ -132,7 +131,7 @@
 /// compatibility.
 
 class actuarial_table
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<actuarial_table>
 {
   public:

Modified: lmi/trunk/any_member.hpp
===================================================================
--- lmi/trunk/authenticity.hpp  2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/authenticity.hpp  2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,10 +29,10 @@
 #include "calendar_date.hpp"
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/filesystem/path.hpp>
 #include <boost/static_assert.hpp>
-#include <boost/utility.hpp>
 
 #include <climits> // CHAR_BIT
 #include <string>
@@ -52,7 +52,7 @@
 /// peremptorily-invalid default value of JDN zero.
 
 class Authenticity
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<Authenticity>
 {
     friend class PasskeyTest;

Modified: lmi/trunk/basic_values.hpp
===================================================================
--- lmi/trunk/basic_values.hpp  2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/basic_values.hpp  2010-12-14 20:39:51 UTC (rev 5127)
@@ -31,10 +31,10 @@
 #include "oecumenic_enumerations.hpp"
 #include "round_to.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 #include "yare_input.hpp"
 
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <string>
 #include <vector>
@@ -80,7 +80,7 @@
     };
 
 class LMI_SO BasicValues
-    :virtual private boost::noncopyable
+    :virtual private lmi::uncopyable
 {
   public:
     BasicValues(Input const& input);

Modified: lmi/trunk/callback.hpp
===================================================================
--- lmi/trunk/census_document.hpp       2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/census_document.hpp       2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,16 +28,15 @@
 
 #include "input.hpp"
 #include "multiple_cell_document.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <wx/docview.h>
 
 class WXDLLIMPEXP_FWD_CORE wxListView;
 
 class CensusDocument
     :public wxDocument
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
     friend class CensusView;
 

Modified: lmi/trunk/census_view.hpp
===================================================================
--- lmi/trunk/census_view.hpp   2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/census_view.hpp   2010-12-14 20:39:51 UTC (rev 5127)
@@ -32,9 +32,9 @@
 #include "ledger.hpp"
 #include "mc_enum_type_enums.hpp" // enum mcenum_emission
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <wx/defs.h> // wx shared-library 'attributes'
 
@@ -47,7 +47,7 @@
 
 class CensusView
     :public ViewEx
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
     ,virtual private obstruct_slicing<CensusView>
 {
     friend class CensusDocument;

Modified: lmi/trunk/commutation_functions.hpp
===================================================================
--- lmi/trunk/commutation_functions.hpp 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/commutation_functions.hpp 2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,15 +29,14 @@
 #include "mc_enum_type_enums.hpp"
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <vector>
 
 /// Ordinary-life commutation functions.
 
 class LMI_SO OLCommFns
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<OLCommFns>
 {
   public:
@@ -84,7 +83,7 @@
 /// for "modal", but would too easily be taken as connoting "monthly".
 
 class LMI_SO ULCommFns
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<ULCommFns>
 {
   public:

Modified: lmi/trunk/configurable_settings.hpp
===================================================================
--- lmi/trunk/configurable_settings.hpp 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/configurable_settings.hpp 2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,10 +29,9 @@
 #include "any_member.hpp"
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 #include "xml_serializable.hpp"
 
-#include <boost/utility.hpp>
-
 #include <string>
 #include <vector>
 
@@ -47,7 +46,7 @@
 /// Data members are documented in their accessors' implementations.
 
 class LMI_SO configurable_settings
-    :        private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing  <configurable_settings>
     ,        public  xml_serializable  <configurable_settings>
     ,        public  MemberSymbolTable <configurable_settings>

Modified: lmi/trunk/database.hpp
===================================================================
--- lmi/trunk/database.hpp      2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/database.hpp      2010-12-14 20:39:51 UTC (rev 5127)
@@ -31,9 +31,8 @@
 #include "mc_enum_type_enums.hpp"
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <string>
 #include <vector>
 
@@ -43,7 +42,7 @@
 /// Database of product parameters.
 
 class LMI_SO product_database
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<product_database>
 {
     friend class input_test;

Modified: lmi/trunk/database_view.hpp
===================================================================
--- lmi/trunk/database_view.hpp 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/database_view.hpp 2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,9 +29,9 @@
 #include "product_editor.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 class DatabaseDocument;
 class DatabaseTableAdapter;
@@ -39,7 +39,7 @@
 
 class DatabaseView
     :public TreeGridViewBase
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
     ,virtual private obstruct_slicing<DatabaseView>
 {
   public:

Modified: lmi/trunk/dbdict.hpp
===================================================================
--- lmi/trunk/dbdict.hpp        2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/dbdict.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -30,16 +30,15 @@
 #include "dbvalue.hpp"
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 #include "xml_serializable.hpp"
 
-#include <boost/utility.hpp>
-
 #include <string>
 
 /// Cached product database.
 
 class LMI_SO DBDictionary
-    :        private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing  <DBDictionary>
     ,        public  xml_serializable  <DBDictionary>
     ,        public  MemberSymbolTable <DBDictionary>

Modified: lmi/trunk/death_benefits.hpp
===================================================================
--- lmi/trunk/death_benefits.hpp        2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/death_benefits.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,15 +28,14 @@
 
 #include "mc_enum_type_enums.hpp"
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <vector>
 
 class yare_input;
 
 class death_benefits
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<death_benefits>
 {
   public:

Modified: lmi/trunk/docmanager_ex.hpp
===================================================================
--- lmi/trunk/docmanager_ex.hpp 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/docmanager_ex.hpp 2010-12-14 20:39:51 UTC (rev 5127)
@@ -26,8 +26,9 @@
 
 #include "config.hpp"
 
+#include "uncopyable_lmi.hpp"
+
 #include <boost/scoped_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <wx/docview.h>
 
@@ -37,7 +38,7 @@
 
 class DocManagerEx
     :public wxDocManager
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
   public:
     explicit DocManagerEx

Modified: lmi/trunk/docmdichildframe_ex.hpp
===================================================================
--- lmi/trunk/docmdichildframe_ex.hpp   2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/docmdichildframe_ex.hpp   2010-12-14 20:39:51 UTC (rev 5127)
@@ -66,13 +66,13 @@
 
 #include "config.hpp"
 
-#include <boost/utility.hpp>
+#include "uncopyable_lmi.hpp"
 
 #include <wx/docmdi.h>
 
 class DocMDIChildFrameEx
     :public wxDocMDIChildFrame
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
   public:
     DocMDIChildFrameEx

Modified: lmi/trunk/fenv_guard.hpp
===================================================================
--- lmi/trunk/fenv_guard.hpp    2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/fenv_guard.hpp    2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,9 +28,8 @@
 
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 /// Guard class for critical floating-point calculations.
 ///
 /// Invariant: the floating-point control word has the desired value.
@@ -43,7 +42,7 @@
 /// floating-point calculations that presume the invariant.
 
 class LMI_SO fenv_guard
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<fenv_guard>
 {
   public:

Modified: lmi/trunk/file_command.hpp
===================================================================
--- lmi/trunk/file_command.hpp  2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/file_command.hpp  2010-12-14 20:39:51 UTC (rev 5127)
@@ -27,9 +27,8 @@
 #include "config.hpp"
 
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <string>
 
 typedef void (*file_command_fp_type)(std::string const&, std::string const&);
@@ -50,7 +49,7 @@
 /// wx, if that ever becomes necessary.
 
 struct LMI_SO file_command
-    :private boost::noncopyable
+    :private lmi::uncopyable
 {
     void operator()(std::string const&, std::string const&) const;
 };

Modified: lmi/trunk/fund_data.hpp
===================================================================
--- lmi/trunk/fund_data.hpp     2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/fund_data.hpp     2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,9 +28,8 @@
 
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <string>
 #include <vector>
 
@@ -66,7 +65,7 @@
 };
 
 class LMI_SO FundData
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<FundData>
 {
   public:

Modified: lmi/trunk/global_settings.hpp
===================================================================
--- lmi/trunk/global_settings.hpp       2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/global_settings.hpp       2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,9 +28,9 @@
 
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/filesystem/path.hpp>
-#include <boost/utility.hpp>
 
 #include <string>
 
@@ -68,7 +68,7 @@
 /// functions to validate their arguments.
 
 class LMI_SO global_settings
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<global_settings>
 {
   public:

Modified: lmi/trunk/icon_monger.hpp
===================================================================
--- lmi/trunk/icon_monger.hpp   2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/icon_monger.hpp   2010-12-14 20:39:51 UTC (rev 5127)
@@ -26,7 +26,7 @@
 
 #include "config.hpp"
 
-#include <boost/utility.hpp>
+#include "uncopyable_lmi.hpp"
 
 #include <wx/artprov.h>
 
@@ -38,7 +38,7 @@
 
 class icon_monger
     :public wxArtProvider
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
   public:
     icon_monger();

Modified: lmi/trunk/ihs_irc7702.hpp
===================================================================
--- lmi/trunk/ihs_irc7702.hpp   2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/ihs_irc7702.hpp   2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,9 +29,9 @@
 #include "mc_enum_type_enums.hpp"
 #include "obstruct_slicing.hpp"
 #include "round_to.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/scoped_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <vector>
 
@@ -56,7 +56,7 @@
 // values are especially needed for the iterative specamt calculation.
 
 class Irc7702
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<Irc7702>
 {
     friend class FindSpecAmt;

Modified: lmi/trunk/illustration_document.hpp
===================================================================
--- lmi/trunk/illustration_document.hpp 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/illustration_document.hpp 2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,9 +28,8 @@
 
 #include "input.hpp"
 #include "single_cell_document.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <wx/docview.h>
 
 /// WX !! The wx document-view implementation has no notion of 'child'
@@ -51,7 +50,7 @@
 
 class IllustrationDocument
     :public wxDocument
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
     friend class IllustrationView;
 

Modified: lmi/trunk/illustration_view.hpp
===================================================================
--- lmi/trunk/illustration_view.hpp     2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/illustration_view.hpp     2010-12-14 20:39:51 UTC (rev 5127)
@@ -37,9 +37,9 @@
 #include "view_ex.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <wx/event.h>
 
@@ -53,7 +53,7 @@
 
 class IllustrationView
     :public ViewEx
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
     ,virtual private obstruct_slicing<IllustrationView>
 {
     friend class IllustrationDocument;

Modified: lmi/trunk/input_sequence.hpp
===================================================================
--- lmi/trunk/input_sequence.hpp        2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/input_sequence.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -201,9 +201,8 @@
 #include "config.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <iosfwd>
 #include <string>
 #include <sstream>
@@ -239,7 +238,7 @@
 };
 
 class InputSequence
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<InputSequence>
 {
   public:

Modified: lmi/trunk/ledger_text_formats.cpp
===================================================================
--- lmi/trunk/ledger_text_formats.cpp   2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/ledger_text_formats.cpp   2010-12-14 20:39:51 UTC (rev 5127)
@@ -45,10 +45,9 @@
 #include "mc_enum_types_aux.hpp" // is_subject_to_ill_reg()
 #include "miscellany.hpp"
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 #include "value_cast.hpp"
 
-#include <boost/utility.hpp>
-
 #include <algorithm>
 #include <fstream>
 #include <functional>
@@ -143,7 +142,7 @@
 }
 
 class calculation_summary_formatter
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<calculation_summary_formatter>
 {
   public:
@@ -683,7 +682,7 @@
 }
 
 class FlatTextLedgerPrinter
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<FlatTextLedgerPrinter>
 {
   public:

Modified: lmi/trunk/ledgervalues.hpp
===================================================================
--- lmi/trunk/ledgervalues.hpp  2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/ledgervalues.hpp  2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,9 +28,9 @@
 
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <string>
 
@@ -42,7 +42,7 @@
 /// This class encapsulates a frequently-used series of operations.
 
 class IllusVal
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<IllusVal>
 {
   public:

Modified: lmi/trunk/loads_impl.hpp
===================================================================
--- lmi/trunk/loads_impl.hpp    2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/loads_impl.hpp    2010-12-14 20:39:51 UTC (rev 5127)
@@ -27,9 +27,8 @@
 #include "config.hpp"
 
 #include "round_to.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <vector>
 
 class BasicValues;
@@ -80,7 +79,7 @@
 /// implemented.
 
 struct load_details
-    :private boost::noncopyable
+    :private lmi::uncopyable
 {
     load_details
         (int                        length

Modified: lmi/trunk/main_wx.hpp
===================================================================
--- lmi/trunk/main_wx.hpp       2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/main_wx.hpp       2010-12-14 20:39:51 UTC (rev 5127)
@@ -37,9 +37,8 @@
 #include "config.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <wx/app.h>
 #include <wx/timer.h>
 
@@ -53,8 +52,8 @@
 class WXDLLIMPEXP_FWD_CORE wxMenuBar;
 
 class Skeleton
-    :public wxApp
-    ,private boost::noncopyable
+    :        public  wxApp
+    ,        private lmi::uncopyable
     ,virtual private obstruct_slicing<Skeleton>
 {
   public:

Modified: lmi/trunk/mec_document.hpp
===================================================================
--- lmi/trunk/mec_document.hpp  2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/mec_document.hpp  2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,9 +28,8 @@
 
 #include "mec_input.hpp"
 #include "mec_xml_document.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <wx/docview.h>
 
 class mec_view;
@@ -38,7 +37,7 @@
 
 class mec_document
     :public wxDocument
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
     friend class mec_view;
 

Modified: lmi/trunk/mec_view.hpp
===================================================================
--- lmi/trunk/mec_view.hpp      2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/mec_view.hpp      2010-12-14 20:39:51 UTC (rev 5127)
@@ -30,9 +30,8 @@
 #include "view_ex.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <wx/event.h>
 
 #include <string>
@@ -64,7 +63,7 @@
 
 class mec_view
     :public ViewEx
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
     ,virtual private obstruct_slicing<mec_view>
 {
     friend class mec_document;

Modified: lmi/trunk/mec_xml_document.hpp
===================================================================
--- lmi/trunk/mec_xml_document.hpp      2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/mec_xml_document.hpp      2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,10 +28,10 @@
 
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 #include "xml_lmi_fwd.hpp"
 
 #include <boost/scoped_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <iosfwd>
 #include <string>
@@ -39,7 +39,7 @@
 class mec_input;
 
 class LMI_SO mec_xml_document
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<mec_xml_document>
 {
     friend class mec_document;

Modified: lmi/trunk/msw_workarounds.hpp
===================================================================
--- lmi/trunk/msw_workarounds.hpp       2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/msw_workarounds.hpp       2010-12-14 20:39:51 UTC (rev 5127)
@@ -27,9 +27,8 @@
 #include "config.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <deque>
 #include <string>
 
@@ -51,7 +50,7 @@
 /// in order to let this reversal be expressed more cleanly.
 
 class MswDllPreloader
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<MswDllPreloader>
 {
   public:

Modified: lmi/trunk/multidimgrid_any.cpp
===================================================================
--- lmi/trunk/multidimgrid_any.cpp      2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/multidimgrid_any.cpp      2010-12-14 20:39:51 UTC (rev 5127)
@@ -213,7 +213,7 @@
 /// an update and it is the place to do it once for all the calls.
 
 class GridRefreshTableDataGuard
-  :private boost::noncopyable
+    :private lmi::uncopyable
 {
   public:
     /// Construct guard for the counter, and use releaser at last exit

Modified: lmi/trunk/multidimgrid_any.hpp
===================================================================
--- lmi/trunk/multidimgrid_any.hpp      2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/multidimgrid_any.hpp      2010-12-14 20:39:51 UTC (rev 5127)
@@ -92,10 +92,10 @@
 
 #include "alert.hpp"
 #include "assert_lmi.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/any.hpp>
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <wx/grid.h>
 #include <wx/choice.h>
@@ -191,7 +191,7 @@
 /// was up-to-date.
 
 class MultiDimAxisAny
-  :private boost::noncopyable
+  :private lmi::uncopyable
 {
   public:
     MultiDimAxisAny(std::string const& name);
@@ -472,7 +472,7 @@
 class MultiDimGrid
   :public wxPanel
   ,private wxGridTableBase
-  ,private boost::noncopyable
+  ,private lmi::uncopyable
 {
     friend class GridRefreshTableDataGuard;
 
@@ -758,7 +758,7 @@
 
 class MultiDimAxisAnyChoice
   :public wxChoice
-  ,private boost::noncopyable
+  ,private lmi::uncopyable
 {
     friend class MultiDimAxisAny;
 

Modified: lmi/trunk/multidimgrid_tools.hpp
===================================================================
--- lmi/trunk/multidimgrid_tools.hpp    2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/multidimgrid_tools.hpp    2010-12-14 20:39:51 UTC (rev 5127)
@@ -30,10 +30,9 @@
 
 #include "alert.hpp"
 #include "safely_dereference_as.hpp"
+#include "uncopyable_lmi.hpp"
 #include "value_cast.hpp"
 
-#include <boost/utility.hpp>
-
 #include <wx/choice.h>
 #include <wx/treectrl.h>
 
@@ -90,8 +89,8 @@
 
 template<typename Integral>
 class AxisMaxBoundAdjuster
-  :public AxisMaxBoundAdjusterBase
-  ,private boost::noncopyable
+    :public AxisMaxBoundAdjusterBase
+    ,private lmi::uncopyable
 {
   public:
     AxisMaxBoundAdjuster

Modified: lmi/trunk/multiple_cell_document.hpp
===================================================================
--- lmi/trunk/multiple_cell_document.hpp        2010-12-14 01:53:40 UTC (rev 
5126)
+++ lmi/trunk/multiple_cell_document.hpp        2010-12-14 20:39:51 UTC (rev 
5127)
@@ -29,16 +29,15 @@
 #include "input.hpp"
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 #include "xml_lmi_fwd.hpp"
 
-#include <boost/utility.hpp>
-
 #include <iosfwd>
 #include <string>
 #include <vector>
 
 class LMI_SO multiple_cell_document
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<multiple_cell_document>
 {
 // TODO ?? Avoid long-distance friendship...in single-cell class, too.

Modified: lmi/trunk/mvc_controller.hpp
===================================================================
--- lmi/trunk/mvc_controller.hpp        2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/mvc_controller.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -27,9 +27,8 @@
 #include "config.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <wx/bookctrl.h> // wxBookCtrlBase, wxBookCtrlBaseEvent
 #include <wx/dialog.h>
 #include <wx/stattext.h>
@@ -409,8 +408,8 @@
 /// Controller.
 
 class MvcController
-    :public wxDialog
-    ,private boost::noncopyable
+    :        public wxDialog
+    ,        private lmi::uncopyable
     ,virtual private obstruct_slicing<MvcController>
 {
     friend class MvcTest;

Modified: lmi/trunk/name_value_pairs.hpp
===================================================================
--- lmi/trunk/name_value_pairs.hpp      2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/name_value_pairs.hpp      2010-12-14 20:39:51 UTC (rev 5127)
@@ -27,9 +27,8 @@
 #include "config.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <map>
 
 /// Design notes for class name_value_pairs.
@@ -85,7 +84,7 @@
 /// extra checks can easily be added if they become desirable.
 
 class name_value_pairs
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<name_value_pairs>
 {
     friend int test_main(int, char*[]);

Modified: lmi/trunk/null_stream.cpp
===================================================================
--- lmi/trunk/null_stream.cpp   2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/null_stream.cpp   2010-12-14 20:39:51 UTC (rev 5127)
@@ -27,9 +27,8 @@
 #endif // __BORLANDC__
 
 #include "null_stream.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <ostream>
 #include <streambuf>
 #include <string>
@@ -47,7 +46,7 @@
 template<typename CharType, typename traits = std::char_traits<CharType> >
 class dev_null_stream_buffer
     :public std::streambuf
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
   public:
     dev_null_stream_buffer()

Modified: lmi/trunk/outlay.hpp
===================================================================
--- lmi/trunk/outlay.hpp        2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/outlay.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,15 +28,14 @@
 
 #include "mc_enum_type_enums.hpp"
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <vector>
 
 class yare_input;
 
 class modal_outlay
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<modal_outlay>
 {
     friend class AccountValue;

Modified: lmi/trunk/policy_view.hpp
===================================================================
--- lmi/trunk/policy_view.hpp   2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/policy_view.hpp   2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,9 +29,8 @@
 #include "product_editor.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <map>
 #include <string>
 
@@ -40,7 +39,7 @@
 
 class PolicyView
     :public ProductEditorView
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
     ,virtual private obstruct_slicing<PolicyView>
 {
   public:

Modified: lmi/trunk/product_data.hpp
===================================================================
--- lmi/trunk/product_data.hpp  2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/product_data.hpp  2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,10 +29,9 @@
 #include "any_member.hpp"
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 #include "xml_serializable.hpp"
 
-#include <boost/utility.hpp>
-
 #include <string>
 
 /// A single product datum: a string with an optional gloss.
@@ -77,7 +76,7 @@
 /// Implicitly-declared special member functions do the right thing.
 
 class LMI_SO product_data
-    :        private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing  <product_data>
     ,        public  xml_serializable  <product_data>
     ,        public  MemberSymbolTable <product_data>

Modified: lmi/trunk/product_editor.hpp
===================================================================
--- lmi/trunk/product_editor.hpp        2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/product_editor.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,7 +28,7 @@
 
 #include "view_ex.hpp"
 
-#include <boost/utility.hpp>
+#include "uncopyable_lmi.hpp"
 
 #include <wx/docview.h>
 
@@ -47,7 +47,7 @@
 
 class ProductEditorDocument
     :public wxDocument
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
   public:
     ProductEditorDocument();
@@ -71,7 +71,7 @@
 
 class ProductEditorView
     :public ViewEx
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
 {
     friend class ProductEditorDocument;
 
@@ -89,7 +89,7 @@
 
 class TreeGridViewBase
     :public ProductEditorView
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
 {
   public:
     TreeGridViewBase();

Modified: lmi/trunk/progress_meter.hpp
===================================================================
--- lmi/trunk/progress_meter.hpp        2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/progress_meter.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -174,9 +174,9 @@
 #include "config.hpp"
 
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <iosfwd>
 #include <string>
@@ -184,7 +184,7 @@
 std::ostringstream& progress_meter_unit_test_stream();
 
 class LMI_SO progress_meter
-    :private boost::noncopyable
+    :private lmi::uncopyable
 {
   public:
     enum enum_display_mode

Modified: lmi/trunk/rounding_rules.hpp
===================================================================
--- lmi/trunk/rounding_rules.hpp        2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/rounding_rules.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -31,10 +31,9 @@
 #include "mc_enum_types.hpp"
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 #include "xml_serializable.hpp"
 
-#include <boost/utility.hpp>
-
 #include <string>
 
 /// Parameters of a rounding rule.
@@ -92,7 +91,7 @@
 /// The 7702 and 7702A interest rate must be rounded up, if at all.
 
 class LMI_SO rounding_rules
-    :        private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing  <rounding_rules>
     ,        public  xml_serializable  <rounding_rules>
     ,        public  MemberSymbolTable <rounding_rules>

Modified: lmi/trunk/rounding_view.hpp
===================================================================
--- lmi/trunk/rounding_view.hpp 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/rounding_view.hpp 2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,9 +29,8 @@
 #include "product_editor.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <map>
 
 class RoundingButtons;
@@ -39,7 +38,7 @@
 
 class RoundingView
     :public ProductEditorView
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
     ,virtual private obstruct_slicing<RoundingView>
 {
   public:

Modified: lmi/trunk/single_cell_document.hpp
===================================================================
--- lmi/trunk/single_cell_document.hpp  2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/single_cell_document.hpp  2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,10 +28,10 @@
 
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 #include "xml_lmi_fwd.hpp"
 
 #include <boost/scoped_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <iosfwd>
 #include <string>
@@ -39,7 +39,7 @@
 class Input;
 
 class LMI_SO single_cell_document
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<single_cell_document>
 {
     friend class IllustrationDocument;

Modified: lmi/trunk/test_coding_rules.cpp
===================================================================
--- lmi/trunk/test_coding_rules.cpp     2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/test_coding_rules.cpp     2010-12-14 20:39:51 UTC (rev 5127)
@@ -33,13 +33,13 @@
 #include "main_common.hpp"
 #include "miscellany.hpp" // lmi_array_size()
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/filesystem/convenience.hpp>
 #include <boost/filesystem/fstream.hpp>
 #include <boost/filesystem/operations.hpp>
 #include <boost/filesystem/path.hpp>
 #include <boost/regex.hpp>
-#include <boost/utility.hpp>
 
 #include <cstddef>        // std::size_t
 #include <ctime>
@@ -109,7 +109,7 @@
     };
 
 class file
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<file>
 {
   public:

Modified: lmi/trunk/text_view.hpp
===================================================================
--- lmi/trunk/text_view.hpp     2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/text_view.hpp     2010-12-14 20:39:51 UTC (rev 5127)
@@ -37,9 +37,8 @@
 #include "view_ex.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <wx/defs.h> // wx shared-library 'attributes'
 
 class WXDLLIMPEXP_FWD_CORE wxTextCtrl;
@@ -54,7 +53,7 @@
 
 class TextEditView
     :public ViewEx
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
     ,virtual private obstruct_slicing<TextEditView>
 {
     friend class TextEditDocument;

Modified: lmi/trunk/tier_view.hpp
===================================================================
--- lmi/trunk/tier_view.hpp     2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/tier_view.hpp     2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,9 +29,9 @@
 #include "product_editor.hpp"
 
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
 #include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
 
 class TierDocument;
 class TierTableAdapter;
@@ -39,7 +39,7 @@
 
 class TierView
     :public TreeGridViewBase
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
     ,virtual private obstruct_slicing<TierView>
 {
   public:

Modified: lmi/trunk/timer.hpp
===================================================================
--- lmi/trunk/timer.hpp 2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/timer.hpp 2010-12-14 20:39:51 UTC (rev 5127)
@@ -27,6 +27,7 @@
 #include "config.hpp"
 
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
 #if defined LMI_POSIX
 #   include <sys/time.h> // gettimeofday()
@@ -49,8 +50,6 @@
     typedef std::clock_t elapsed_t;
 #endif // Unknown platform.
 
-#include <boost/utility.hpp>
-
 #include <iomanip>
 #include <ios>
 #include <ostream>
@@ -75,7 +74,7 @@
 /// elapsed_msec_str(), elapsed_usec(), stop(), restart(): nomen est omen.
 
 class LMI_SO Timer
-    :private boost::noncopyable
+    :private lmi::uncopyable
 {
     friend class TimerTest;
     template<typename F> friend class AliquotTimer;

Modified: lmi/trunk/transferor.hpp
===================================================================
--- lmi/trunk/uncopyable_lmi.hpp                                (rev 0)
+++ lmi/trunk/uncopyable_lmi.hpp        2010-12-14 20:39:51 UTC (rev 5127)
@@ -0,0 +1,42 @@
+// Copyright (C) 2010 Gregory W. Chicares.
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License version 2 as
+// published by the Free Software Foundation.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
+//
+// http://savannah.nongnu.org/projects/lmi
+// email: <address@hidden>
+// snail: Chicares, 186 Belle Woods Drive, Glastonbury CT 06033, USA
+
+// $Id$
+
+#ifndef uncopyable_lmi_hpp
+#define uncopyable_lmi_hpp
+
+#include "config.hpp"
+
+namespace lmi
+{
+class uncopyable
+{
+  protected:
+    uncopyable() {}
+    ~uncopyable() {}
+
+  private:
+    uncopyable(uncopyable const&);
+    uncopyable& operator=(uncopyable const&);
+};
+} // namespace lmi
+
+#endif // uncopyable_lmi_hpp
+


Property changes on: lmi/trunk/uncopyable_lmi.hpp
___________________________________________________________________
Added: svn:keywords
   + Id

Modified: lmi/trunk/view_ex.hpp
===================================================================
--- lmi/trunk/view_ex.hpp       2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/view_ex.hpp       2010-12-14 20:39:51 UTC (rev 5127)
@@ -79,7 +79,7 @@
 
 #include "config.hpp"
 
-#include <boost/utility.hpp>
+#include "uncopyable_lmi.hpp"
 
 #include <wx/docview.h>
 
@@ -110,7 +110,7 @@
 
 class ViewEx
     :public wxView
-    ,virtual private boost::noncopyable
+    ,virtual private lmi::uncopyable
 {
   public:
     ViewEx();

Modified: lmi/trunk/xml_lmi.hpp
===================================================================
--- lmi/trunk/xml_lmi.hpp       2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/xml_lmi.hpp       2010-12-14 20:39:51 UTC (rev 5127)
@@ -26,10 +26,10 @@
 
 #include "config.hpp"
 
+#include "uncopyable_lmi.hpp"
 #include "xml_lmi_fwd.hpp"
 
 #include <boost/scoped_ptr.hpp>
-#include <boost/utility.hpp>
 
 #include <xmlwrapp/node.h> // (for xml::element)
 
@@ -42,7 +42,7 @@
 namespace xml_lmi
 {
     class dom_parser
-        :private boost::noncopyable
+        :private lmi::uncopyable
     {
         typedef xml::tree_parser DomParser;
 
@@ -61,7 +61,7 @@
     };
 
     class xml_document
-        :private boost::noncopyable
+        :private lmi::uncopyable
     {
       public:
         xml_document(std::string const& root_node_name);

Modified: lmi/trunk/yare_input.hpp
===================================================================
--- lmi/trunk/yare_input.hpp    2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/yare_input.hpp    2010-12-14 20:39:51 UTC (rev 5127)
@@ -29,9 +29,8 @@
 #include "calendar_date.hpp"
 #include "mc_enum_type_enums.hpp"
 #include "obstruct_slicing.hpp"
+#include "uncopyable_lmi.hpp"
 
-#include <boost/utility.hpp>
-
 #include <string>
 #include <vector>
 
@@ -56,7 +55,7 @@
 /// (mc_enum and tn_range classes) designed for interactive input.
 
 class yare_input
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<yare_input>
 {
   public:




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- lmi/trunk/any_member.hpp    2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/any_member.hpp    2010-12-14 20:39:51 UTC (rev 5127)
@@ -67,6 +67,7 @@
 #include "assert_lmi.hpp"
 #include "obstruct_slicing.hpp"
 #include "rtti_lmi.hpp"
+#include "uncopyable_lmi.hpp"
 #include "value_cast.hpp"
 
 #if !defined __BORLANDC__
@@ -77,8 +78,6 @@
 #   define BOOST_STATIC_ASSERT(deliberately_ignored) class IgNoRe
 #endif // defined __BORLANDC__
 
-#include <boost/utility.hpp>
-
 #include <algorithm> // std::lower_bound(), std::swap()
 #include <map>
 #include <sstream>
@@ -122,7 +121,7 @@
 template<typename ClassType, typename ValueType>
 class holder
     :public placeholder
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
     // Friendship is extended to class any_member only to support its
     // cast operations.
@@ -518,11 +517,11 @@
 
 // Definition of class MemberSymbolTable.
 
 // By its nature, this class is Noncopyable: it holds a map of
 // pointers to member, which need to be initialized instead of copied
 // when a derived class is copied. Its Noncopyability is implemented
 // natively: deriving from boost::noncopyable would prevent class C
 // from deriving from MemberSymbolTable<C> and boost::noncopyable.
 //
 // A do-nothing constructor is specified in order to prevent compilers
 // from warning of its absence. It's protected because this class
@@ -518,11 +517,11 @@
 // Definition of class MemberSymbolTable.
 
-// By its nature, this class is Noncopyable: it holds a map of
+// By its nature, this class is uncopyable: it holds a map of
 // pointers to member, which need to be initialized instead of copied
@@ -518,11 +517,11 @@
 // pointers to member, which need to be initialized instead of copied
-// when a derived class is copied. Its Noncopyability is implemented
-// natively: deriving from boost::noncopyable would prevent class C
-// from deriving from MemberSymbolTable<C> and boost::noncopyable.
+// when a derived class is copied. Its uncopyability is implemented
+// natively: deriving from lmi::uncopyable would prevent class C
+// from deriving from MemberSymbolTable<C> and lmi::uncopyable.
 //
 // A do-nothing constructor is specified in order to prevent compilers

Modified: lmi/trunk/authenticity.hpp
===================================================================
--- lmi/trunk/callback.hpp      2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/callback.hpp      2010-12-14 20:39:51 UTC (rev 5127)
@@ -28,6 +28,7 @@
 
 #include "obstruct_slicing.hpp"
 #include "so_attributes.hpp"
+#include "uncopyable_lmi.hpp"
 
 #if !defined __BORLANDC__
 #   include <boost/static_assert.hpp>
@@ -36,8 +37,6 @@
 #   include <boost/type_traits/remove_pointer.hpp>
 #endif // !defined __BORLANDC__
 
-#include <boost/utility.hpp>
-
 #include <stdexcept>
 
 /// Design notes for class callback.
@@ -89,7 +88,7 @@
 /// pointer to a nonmember function. Probably it would be easy to
 /// permit a pointer to member function as well.
 ///
 /// This class is noncopyable and cannot be derived from, not because
 /// it would be difficult to allow those things, but because they seem
 /// pointless.
 ///
@@ -106,7 +105,7 @@
 
 template<typename FunctionPointer>
 class LMI_SO callback
-    :private boost::noncopyable
+    :        private lmi::uncopyable
     ,virtual private obstruct_slicing<callback<FunctionPointer> >
 {
 #if !defined __BORLANDC__
@@ -89,7 +88,7 @@
 /// permit a pointer to member function as well.
 ///
-/// This class is noncopyable and cannot be derived from, not because
+/// This class is uncopyable and cannot be derived from, not because
 /// it would be difficult to allow those things, but because they seem
 /// pointless.

Modified: lmi/trunk/census_document.hpp
===================================================================
--- lmi/trunk/transferor.hpp    2010-12-14 01:53:40 UTC (rev 5126)
+++ lmi/trunk/transferor.hpp    2010-12-14 20:39:51 UTC (rev 5127)
@@ -34,7 +34,7 @@
 
 #include "config.hpp"
 
-#include <boost/utility.hpp>
+#include "uncopyable_lmi.hpp"
 
 #include <wx/validate.h>
 
@@ -105,7 +105,7 @@
 ///
 /// The wx documentation says "All validator classes must implement the
 /// Clone function, which returns an identical copy of itself." The
 /// base class is Noncopyable, although it has a nonvirtual Copy()
 /// function that it is apparently safe to ignore here.
 ///
 /// Boost coding guideline 15.5 warns that reference members preclude
@@ -117,7 +117,7 @@
 
 class Transferor
     :public wxValidator
-    ,private boost::noncopyable
+    ,private lmi::uncopyable
 {
   public:
     Transferor(std::string& data, std::string const& name);
@@ -105,7 +105,7 @@
 /// The wx documentation says "All validator classes must implement the
 /// Clone function, which returns an identical copy of itself." The
-/// base class is Noncopyable, although it has a nonvirtual Copy()
+/// base class is uncopyable, although it has a nonvirtual Copy()
 /// function that it is apparently safe to ignore here.
 ///

Added: lmi/trunk/uncopyable_lmi.hpp
===================================================================